@@ -47,6 +47,7 @@ _NON_WAYBACK_URLS: set[str] = {
     "https://www.pro-football-reference.com/boxscores/202502090phi.htm",
     "https://www.sports-reference.com/cfb/boxscores/2025-01-09-penn-state.html",
     "https://www.sports-reference.com/cfb/boxscores/2024-12-31-alabama.html",
+    "https://www.hockey-reference.com/boxscores/202410050NJD.html",
 }
 
 
@@ -1412,6 +1413,7 @@ def _create_sportsreference_game_model(
             .replace("Arena:", "")
             .replace("Copyright", "")
             .replace("Venue:", "")
+            .replace("Game", "")
         )
 
     try:
